@@ -1,20 +1,24 @@
 """Tools for describing a player character."""
 __all__ = ('Character',)
 
-import re
-import os
-import warnings
-from . import exceptions
+from pathlib import Path
 import importlib.util
-import jinja2
-import subprocess
+import os
+import re
+import warnings
+import math
 
-from .stats import Ability, Skill, findattr, ArmorClass, Speed, Initiative
-from .dice import read_dice_str
-from . import (weapons, race, background, spells, armor, monsters,
-               exceptions, classes, features, magic_items)
-from .weapons import Weapon
-from .armor import Armor, NoArmor, Shield, NoShield
+import jinja2
+
+from dungeonsheets import (armor, background, classes, exceptions, features,
+                           infusions, magic_items, monsters, race, spells,
+                           weapons)
+from dungeonsheets.armor import Armor, NoArmor, NoShield, Shield
+from dungeonsheets.dice import read_dice_str
+from dungeonsheets.stats import (Ability, ArmorClass, Initiative, Skill, Speed,
+                                 findattr)
+from dungeonsheets.weapons import Weapon
+from dungeonsheets.readers import read_character_file
 
 
 def read(fname):
@@ -26,7 +30,7 @@ __version__ = read('../VERSION').strip()
 
 dice_re = re.compile('(\d+)d(\d+)')
 
-__all__ = ('Barbarian', 'Bard', 'Cleric', 'Druid', 'Fighter', 'Monk',
+__all__ = ('Artificer', 'Barbarian', 'Bard', 'Cleric', 'Druid', 'Fighter', 'Monk',
            'Paladin', 'Ranger', 'Rogue', 'Sorcerer', 'Warlock', 'Wizard', )
 
 multiclass_spellslots_by_level = {
@@ -56,7 +60,7 @@ multiclass_spellslots_by_level = {
 
 class Character():
     """A generic player character.
-    
+
     """
     # General attirubtes
     name = ""
@@ -68,7 +72,7 @@ class Character():
     _background = None
     xp = 0
     # Hit points
-    hp_max = 10
+    hp_max = None
     # Base stats (ability scores)
     strength = Ability()
     dexterity = Ability()
@@ -79,7 +83,7 @@ class Character():
     armor_class = ArmorClass()
     initiative = Initiative()
     speed = Speed()
-    inspiration = 0
+    inspiration = False
     _saving_throw_proficiencies = tuple()  # use to overwrite class proficiencies
     other_weapon_proficiencies = tuple()  # add to class/race proficiencies
     skill_proficiencies = list()
@@ -127,10 +131,11 @@ class Character():
     spellcasting_ability = None
     _spells = list()
     _spells_prepared = list()
+    infusions = list()
     # Features IN MAJOR DEVELOPMENT
     custom_features = list()
     feature_choices = list()
-    
+
     def __init__(self, **attrs):
         """Takes a bunch of attrs and passes them to ``set_attrs``"""
         self.clear()
@@ -157,6 +162,7 @@ class Character():
         self.background = attrs.pop('background', None)
         # parse all other attributes
         self.set_attrs(**attrs)
+        self.__set_max_hp(attrs.get('hp_max', None))
 
     def clear(self):
         # reset class-definied items
@@ -170,12 +176,13 @@ class Character():
         self._proficiencies_text = list()
         self._spells = list()
         self._spells_prepared = list()
+        self.infusions = list()
         self.custom_features = list()
         self.feature_choices = list()
-                
+
     def __str__(self):
         return self.name
-    
+
     def __repr__(self):
         return f"<{self.class_name}: {self.name}>"
 
@@ -193,7 +200,7 @@ class Character():
         self.class_list.append(cls(level, owner=self,
                                    subclass=subclass,
                                    feature_choices=feature_choices))
-            
+
     def add_classes(self, classes_list=[], levels=[], subclasses=[],
                     feature_choices=[]):
         if isinstance(classes_list, str):
@@ -218,7 +225,7 @@ class Character():
             params['feature_choices'] = feature_choices
             self.add_class(cls=cls, level=lvl, subclass=sub,
                            **params)
-    
+
     @property
     def race(self):
         return self._race
@@ -240,7 +247,7 @@ class Character():
                 warnings.warn(msg)
         elif newrace is None:
             self._race = race.Race(owner=self)
-        
+
     @property
     def background(self):
         return self._background
@@ -280,11 +287,11 @@ class Character():
     @property
     def levels(self):
         return [c.level for c in self.class_list]
-    
+
     @property
     def subclasses(self):
         return list([c.subclass or '' for c in self.class_list])
-    
+
     @property
     def level(self):
         return sum(c.level for c in self.class_list)
@@ -295,7 +302,7 @@ class Character():
         if self.num_classes > 1:
             warnings.warn("Unable to tell which level to set. Updating "
                           "level of primary class {:s}".format(self.primary_class.name))
-    
+
     @property
     def num_classes(self):
         return len(self.class_list)
@@ -312,6 +319,25 @@ class Character():
         else:
             return None
 
+    def __set_max_hp(self, hp_max):
+        """
+        Set maximum HP based on value in charlist py or calc from classes
+        """
+        if hp_max:
+            assert isinstance(hp_max, int), hp_max.__class__
+            self.hp_max = hp_max
+        else:
+            const_mod = self.constitution.modifier
+            level_one_hp = self.primary_class.hit_dice_faces + const_mod
+            self.hp_max = level_one_hp
+            for char_cls in self.class_list:
+                hp_per_lvl = char_cls.hit_dice_faces/2 + 1 + const_mod
+                levels = char_cls.level
+                if char_cls == self.primary_class:
+                    levels -= 1
+                assert levels >= 0
+                self.hp_max += int(hp_per_lvl * levels)
+
     @property
     def weapon_proficiencies(self):
         wp = set(self.other_weapon_proficiencies)
@@ -325,7 +351,7 @@ class Character():
         if self.background is not None:
             wp |= set(getattr(self.background, 'weapon_proficiencies', ()))
         return tuple(wp)
-    
+
     @weapon_proficiencies.setter
     def weapon_proficiencies(self, new_weapons):
         self.other_weapon_proficiencies = tuple(new_weapons)
@@ -377,7 +403,7 @@ class Character():
 
     def has_feature(self, feat):
         return any([isinstance(f, feat) for f in self.features])
-    
+
     @property
     def saving_throw_proficiencies(self):
         if self.primary_class is None:
@@ -393,14 +419,24 @@ class Character():
     @property
     def spellcasting_classes(self):
         return [c for c in self.class_list if c.is_spellcaster]
-    
+
+    @property
+    def spellcasting_classes_excluding_warlock(self):
+        return [c for c in self.spellcasting_classes if not type(c) == classes.Warlock]
+
     @property
     def is_spellcaster(self):
         return (len(self.spellcasting_classes) > 0)
 
     def spell_slots(self, spell_level):
-        if len(self.spellcasting_classes) == 1:
-            return self.spellcasting_classes[0].spell_slots(spell_level)
+        warlock_slots = 0
+        for c in self.spellcasting_classes:
+            if type(c) is classes.Warlock:
+                warlock_slots = c.spell_slots(spell_level)
+        if len(self.spellcasting_classes_excluding_warlock) == 0:
+            return warlock_slots
+        if len(self.spellcasting_classes_excluding_warlock) == 1:
+            return self.spellcasting_classes_excluding_warlock[0].spell_slots(spell_level) + warlock_slots
         else:
             if spell_level == 0:
                 return sum([c.spell_slots(0)
@@ -408,7 +444,7 @@ class Character():
             else:
                 # compute effective level from PHB pg 164
                 eff_level = 0
-                for c in self.spellcasting_classes:
+                for c in self.spellcasting_classes_excluding_warlock:
                     if type(c) in [classes.Bard, classes.Cleric, classes.Druid,
                                    classes.Sorceror, classes.Wizard]:
                         eff_level += c.level
@@ -416,10 +452,12 @@ class Character():
                         eff_level += c.level // 2
                     elif type(c) in [classes.Fighter, classes.Rogue]:
                         eff_level += c.level // 3
+                    elif type(c) is classes.Artificer:
+                        eff_level += math.ceil(c.level / 2)
                 if eff_level == 0:
-                    return 0
+                    return warlock_slots
                 else:
-                    return multiclass_spellslots_by_level[eff_level][spell_level]
+                    return multiclass_spellslots_by_level[eff_level][spell_level] + warlock_slots
 
     @property
     def spells(self):
@@ -431,7 +469,7 @@ class Character():
         if self.race is not None:
             spells |= set(self.race.spells_known) | set(self.race.spells_prepared)
         return sorted(tuple(spells), key=(lambda x: (x.name)))
-            
+
     @property
     def spells_prepared(self):
         spells = set(self._spells_prepared)
@@ -444,8 +482,10 @@ class Character():
         return sorted(tuple(spells), key=(lambda x: (x.name)))
 
     def set_attrs(self, **attrs):
-        """Bulk setting of attributes. Useful for loading a character from a
-        dictionary."""
+        """
+        Bulk setting of attributes
+        Useful for loading a character from a dictionary
+        """
         for attr, val in attrs.items():
             if attr == 'dungeonsheets_version':
                 pass # Maybe we'll verify this later?
@@ -515,6 +555,18 @@ class Character():
                 else:
                     # Instantiate them all for the spells list
                     self._spells_prepared = tuple(S() for S in _spells)
+            elif attr == 'infusions':
+                if hasattr(self, 'Artificer'):
+                    _infusions = []
+                    for infusion_name in val:
+                        try:
+                            _infusions.append(findattr(infusions, infusion_name))
+                        except AttributeError:
+                            msg = (f'Infusion "{infusion_name}" not defined. '
+                                   f'Please add it to ``infusions.py``')
+                            warnings.warn(msg)
+                    _infusions.sort(key=lambda infusion: infusion.name)
+                    self.infusions = tuple(i() for i in _infusions)
             else:
                 if not hasattr(self, attr):
                     warnings.warn(f"Setting unknown character attribute {attr}",
@@ -525,16 +577,16 @@ class Character():
     def spell_save_dc(self, class_type):
         ability_mod = getattr(self, class_type.spellcasting_ability).modifier
         return (8 + self.proficiency_bonus + ability_mod)
-    
+
     def spell_attack_bonus(self, class_type):
         ability_mod = getattr(self, class_type.spellcasting_ability).modifier
         return (self.proficiency_bonus + ability_mod)
 
     def is_proficient(self, weapon: Weapon):
         """Is the character proficient with this item?
-        
+
         Considers class proficiencies and race proficiencies.
-        
+
         Parameters
         ----------
         weapon
@@ -543,12 +595,12 @@ class Character():
         Returns
         -------
         Boolean: is this character proficient with this weapon?
-        
+
         """
         all_proficiencies = self.weapon_proficiencies
         is_proficient = any((isinstance(weapon, W) for W in all_proficiencies))
         return is_proficient
-    
+
     @property
     def proficiencies_text(self):
         final_text = ""
@@ -584,7 +636,7 @@ class Character():
             s = '(See Features Page)\n\n--' + s
             s += '\n\n=================\n\n'
         return s
-    
+
     @property
     def magic_items_text(self):
         s = ', '.join([f.name + ("**" if f.needs_implementation else "")
@@ -592,16 +644,16 @@ class Character():
         if s:
             s += ', '
         return s
-    
+
     def wear_armor(self, new_armor):
         """Accepts a string or Armor class and replaces the current armor.
-        
+
         If a string is given, then a subclass of
         :py:class:`~dungeonsheets.armor.Armor` is retrived from the
         ``armor.py`` file. Otherwise, an subclass of
         :py:class:`~dungeonsheets.armor.Armor` can be provided
         directly.
-        
+
         """
         if new_armor not in ('', 'None', None):
             if isinstance(new_armor, armor.Armor):
@@ -610,16 +662,16 @@ class Character():
                 NewArmor = findattr(armor, new_armor)
                 new_armor = NewArmor()
             self.armor = new_armor
-    
+
     def wield_shield(self, shield):
         """Accepts a string or Shield class and replaces the current armor.
-        
+
         If a string is given, then a subclass of
         :py:class:`~dungeonsheets.armor.Shield` is retrived from the
         ``armor.py`` file. Otherwise, an subclass of
         :py:class:`~dungeonsheets.armor.Shield` can be provided
         directly.
-        
+
         """
         if shield not in ('', 'None', None):
             try:
@@ -628,15 +680,15 @@ class Character():
                 # Not a string, so just treat it as Armor
                 NewShield = shield
             self.shield = NewShield()
-    
+
     def wield_weapon(self, weapon):
         """Accepts a string and adds it to the list of wielded weapons.
-        
+
         Parameters
         ----------
         weapon : str
           Case-insensitive string with a name of the weapon.
-        
+
         """
         # Retrieve the weapon class from the weapons module
         if isinstance(weapon, weapons.Weapon):
@@ -645,7 +697,10 @@ class Character():
             try:
                 NewWeapon = findattr(weapons, weapon)
             except AttributeError:
-                raise AttributeError(f'Weapon "{weapon}" is not defined')
+                warnings.warn(f"Unknown weapon '{weapon}'. Please add it to ``weapons.py`` "
+                              "or submit an issue: https://github.com/canismarko/dungeon-sheets/issues",
+                              RuntimeWarning)
+                return
             weapon_ = NewWeapon(wielder=self)
         elif issubclass(weapon, weapons.Weapon):
             weapon_ = weapon(wielder=self)
@@ -653,11 +708,11 @@ class Character():
             raise AttributeError(f'Weapon "{weapon}" is not defined')
         # Save it to the array
         self.weapons.append(weapon_)
-    
+
     @property
     def hit_dice(self):
         """What type and how many dice to use for re-gaining hit points.
-        
+
         To change, set hit_dice_num and hit_dice_faces."""
         return ' + '.join([f'{c.level}d{c.hit_dice_faces}'
                            for c in self.class_list])
@@ -668,11 +723,11 @@ class Character():
         if self.num_classes > 1:
             warnings.warn("hit_dice_faces is not valid for multiclass characters")
         return self.primary_class.hit_dice_faces
-    
+
     @hit_dice_faces.setter
     def hit_dice_faces(self, faces):
         self.primary_class.hit_dice_faces = faces
-    
+
     @property
     def proficiency_bonus(self):
         if self.level < 5:
@@ -686,7 +741,7 @@ class Character():
         elif 17 <= self.level:
             prof = 6
         return prof
-    
+
     def can_assume_shape(self, shape: monsters.Monster):
         return hasattr(self, 'Druid') and self.Druid.can_assume_shape(shape)
 
@@ -709,6 +764,13 @@ class Character():
         if hasattr(self, 'Druid'):
             self.Druid.wild_shapes = new_shapes
 
+    @property
+    def infusions_text(self):
+        if hasattr(self, 'Artificer'):
+            return tuple([i.name for i in self.infusions])
+        else:
+            return ()
+
     @classmethod
     def load(cls, character_file):
         # Create a character from the character definition
@@ -737,62 +799,27 @@ class Character():
             f.write(text)
 
     def to_pdf(self, filename, **kwargs):
-        from .make_sheets import make_sheet
+        from dungeonsheets.make_sheets import make_sheet
         if filename.endswith('.pdf'):
             filename = filename.replace('pdf', 'py')
         make_sheet(filename, character=self,
                    flatten=kwargs.get('flatten', True))
 
-        
-def read_character_file(filename):
-    """Create a character object from the given definition file.
-    
-    The definition file should be an importable python file, filled
-    with variables describing the character.
-    
-    Parameters
-    ----------
-    filename : str
-      The path to the file that will be imported.
-    
-    """
-    # Parse the file name
-    dir_, fname = os.path.split(os.path.abspath(filename))
-    module_name, ext = os.path.splitext(fname)
-    if ext != '.py':
-        raise ValueError(f"Character definition {filename} is not a python file.")
-    # Check if this file contains the version string
-    version_re = re.compile('dungeonsheets_version\s*=\s*[\'"]([0-9.]+)[\'"]')
-    with open(filename, mode='r') as f:
-        version = None
-        for line in f:
-            match = version_re.match(line)
-            if match:
-                version = match.group(1)
-                break
-        if version is None:
-            # Not a valid DND character file
-            raise exceptions.CharacterFileFormatError(
-                f"No ``dungeonsheets_version = `` entry in `{filename}`.")
-    # Import the module to extract the information
-    spec = importlib.util.spec_from_file_location('module', filename)
-    module = importlib.util.module_from_spec(spec)
-    spec.loader.exec_module(module)
-    # Prepare a list of properties for this character
-    char_props = {}
-    for prop_name in dir(module):
-        if prop_name[0:2] != '__':
-            char_props[prop_name] = getattr(module, prop_name)
-    return char_props
-
 
 # Add backwards compatability for tests
+class Artificer(Character):
+    def __init__(self, level=1, **attrs):
+        attrs['classes'] = ['Artificer']
+        attrs['levels'] = [level]
+        super().__init__(**attrs)
+
+
 class Barbarian(Character):
     def __init__(self, level=1, **attrs):
         attrs['classes'] = ['Barbarian']
         attrs['levels'] = [level]
         super().__init__(**attrs)
-    
+
 
 class Bard(Character):
     def __init__(self, level=1, **attrs):
@@ -869,4 +896,3 @@ class Wizard(Character):
         attrs['classes'] = ['Wizard']
         attrs['levels'] = [level]
         super().__init__(**attrs)
-
