@@ -12,3 +12,9 @@ class LatexNotFoundError(LatexError):
 
 class MonsterError(AttributeError):
     """Error retriving or using a D&D Monster."""
+
+class JSONFormatError(RuntimeError):
+    """The JSON file doesn't conform to the understood formats."""
+
+class UnknownFileType(RuntimeError):
+    """The input file does not match one of the known formats."""
