@@ -3,20 +3,21 @@
 import logging
 log = logging.getLogger(__name__)
 import argparse
-import importlib.util
 import os
 import subprocess
 import warnings
 import re
-from io import StringIO
+from pathlib import Path
+from multiprocessing import Pool, cpu_count
+from itertools import product
 
 from fdfgen import forge_fdf
 import pdfrw
 from jinja2 import Environment, PackageLoader
 
-from . import character as _char
-from . import exceptions, classes
-from .stats import mod_str
+from dungeonsheets import character as _char
+from dungeonsheets import exceptions, classes, readers
+from dungeonsheets.stats import mod_str
 
 
 """Program to take character definitions and build a PDF of the
@@ -25,25 +26,139 @@ character sheet."""
 bold_re = re.compile(r'\*\*([^*]+)\*\*')
 it_re = re.compile(r'\*([^*]+)\*')
 verb_re = re.compile(r'``([^`]+)``')
+heading_re = re.compile(r'^[ \t\r\f\v]*(.+)\n\s*([-=\^]+)$', flags=re.MULTILINE)
 # A dice string, with optinal backticks: ``1d6 + 3``
 dice_re = re.compile(r'`*(\d+d\d+(?:\s*\+\s*\d+)?)`*')
+# What defines a list in reST:
+# - a blank line
+# - one or more of the following
+#   - "- [a-z]"
+#   - an additional line of text (if multi-line bullets)
+#   - a blank line
+# - a blank line
+# - a non-list line or end of file
+# list_re = re.compile('^[ \t\r\f\v]*\n((?:\s*[-*+]\s+[^\n]*\n)+)', flags=re.MULTILINE)
+list_re = re.compile(r'^[ \t\r\f\v]*\n'  # A blank line
+                     r'((?:\s*[-*+]\s+[^\n]*\n)+)' # The first line of each list item
+                     '',
+                     flags=re.MULTILINE)
+# What defines a list item in reST:
+# - a line starting with "- " then some text
+# - zero or more lines starting with anything other than "- "
+list_item_re = re.compile(r'^\s*[-*+]\s+', flags=re.MULTILINE)
 
 
-def rst_to_latex(rst):
-    """Basic markup of RST to LaTeX code."""
+def _parse_rst_lists(rst):
+    """Read lists in reST and iterate.
+
+    Yields
+    ======
+    list_rst : str
+      The matching reST list found in the input text
+    list_items : list
+      A python list of the items found in the reST list.
+    
+    """
+    for match in list_re.finditer(rst):
+        list_rst = match.group(0)
+        # Separate the list items
+        list_items = list_item_re.split(match.group(1))
+        # Clean up separated list items
+        list_items = list_items[1:]  # First item is an empty string
+        list_items = [item.replace('\n', ' ').strip() for item in list_items]
+        yield list_rst, list_items
+
+def _parse_rst_headings(rst):
+    """Read headings in reST and iterate.
+    
+    Yields
+    ======
+    heading_rst : str
+      The matching reST heading found in the input text.
+    heading : str
+      The text of the heading with underlining removed.
+    level : int
+      How deep the heading is: 0 is top-level, 1 is next level down,
+      etc.
+    
+    """
+    heading_levels = {
+        '=': 0,
+        '-': 1,
+        '^': 2,
+    }
+    for match in heading_re.finditer(rst):
+        heading_rst = match.group(0)
+        heading, underline = match.groups()
+        # Check for valid heading
+        if len(underline) < len(heading):
+            log.debug("Skipping malformed reST heading: '%s\n%s'", heading, underline)
+            continue
+        if len(set(underline)) > 1:
+            log.debug("Skipping malformed reST heading: '%s\n%s'", heading, underline)
+            continue
+        # Valid heading, so determine how many levels deep it is
+        level = heading_levels[underline[0]]
+        yield heading_rst, heading, level
+
+
+def rst_to_latex(rst, top_heading_level=0):
+    """Basic markup of reST to LaTeX code.
+    
+    The translation between reST headings and LaTeX headings is
+    modified by the *top_heading_level* parameter. A value of 0
+    (default) translates "# Heading" -> "\section{Heading}". A value
+    of 1 translates "# Heading" -> "\subsection{Heading}", etc.
+    
+    Parameters
+    ==========
+    rst
+      reStructured text input to be parsed.
+    top_heading_level : optional
+      The highest level heading that will be added to the LaTeX as
+      described above.
+    
+    Returns
+    =======
+    tex : str
+      The reST text parsed into LaTeX markup.
+    
+    """
+    heading_latex = {
+        0: 'section*',
+        1: 'subsection*',
+        2: 'subsubsection*',
+        3: 'paragraph*',
+        4: 'subparagraph*',
+        }
     if rst is None:
+        # No reST, so return an empty string
         tex = ""
     else:
         tex = rst
+        # Allow literal backslashes
         for c in ['\\']:
             tex = tex.replace(c, '\\' + c)
+        # Lists
+        for list_rst, list_items in _parse_rst_lists(tex):
+            list_tex = "\n\\begin{itemize}\n"
+            for item in list_items:
+                list_tex += f"\\item{{{item}}}\n"
+            list_tex += "\\end{itemize}\n"
+            tex = tex.replace(list_rst, list_tex)
+        # Inline text formatting
         tex = bold_re.sub(r'\\textbf{\1}', tex)
         tex = it_re.sub(r'\\textit{\1}', tex)
         tex = verb_re.sub(r'\\begin{verbatim}{\1}\\end{verbatim}', tex)
         tex = dice_re.sub(r'\\texttt{\1}', tex)
+        # Headings
+        for heading_rst, heading, heading_level in _parse_rst_headings(tex):
+            heading_level = min(heading_level + top_heading_level, max(heading_latex.keys()))
+            tex = tex.replace(heading_rst, f"\\{heading_latex[heading_level]}{{{heading}}}")
+        # Escape any remaining characters that have meaning in LaTeX
         for c in ['#', '$', '%', '&', '~', '_', '^']:
             tex = tex.replace(c, '\\' + c)
-        
+
     return tex
 
 
@@ -72,35 +187,40 @@ def text_box(string):
     return new_string
 
 
-def create_druid_shapes_pdf(character, basename, keep_temp_files=False):
+def create_druid_shapes_pdf(character, basename, keep_temp_files=False, use_dnd_decorations=False):
     template = jinja_env.get_template('druid_shapes_template.tex')
-    return create_latex_pdf(character, basename, template, keep_temp_files=keep_temp_files)
+    return create_latex_pdf(character, basename, template,
+                            keep_temp_files=keep_temp_files,
+                            use_dnd_decorations=use_dnd_decorations)
 
 
-def create_spellbook_pdf(character, basename, keep_temp_files=False):
+def create_infusions_pdf(character, basename, keep_temp_files=False, use_dnd_decorations=False):
+    template = jinja_env.get_template('infusions_template.tex')
+    return create_latex_pdf(character, basename, template,
+                            keep_temp_files=keep_temp_files,
+                            use_dnd_decorations=use_dnd_decorations)
+
+
+def create_spellbook_pdf(character, basename, keep_temp_files=False, use_dnd_decorations=False):
     template = jinja_env.get_template('spellbook_template.tex')
-    return create_latex_pdf(character, basename, template, keep_temp_files=keep_temp_files)
+    return create_latex_pdf(character, basename, template,
+                            keep_temp_files=keep_temp_files,
+                            use_dnd_decorations=use_dnd_decorations)
 
 
-def create_features_pdf(character, basename, keep_temp_files=False):
+def create_features_pdf(character, basename, keep_temp_files=False, use_dnd_decorations=False):
     template = jinja_env.get_template('features_template.tex')
-    return create_latex_pdf(character, basename, template, keep_temp_files=keep_temp_files)
+    return create_latex_pdf(character, basename, template,
+                            keep_temp_files=keep_temp_files,
+                            use_dnd_decorations=use_dnd_decorations)
 
 
-def create_latex_pdf(character, basename, template, keep_temp_files=False):
-    tex = template.render(character=character)
+def create_latex_pdf(character, basename, template, keep_temp_files=False, use_dnd_decorations=False):
+    tex = template.render(character=character, use_dnd_decorations=use_dnd_decorations)
     # Create tex document
     tex_file = f'{basename}.tex'
     with open(tex_file, mode='w', encoding="utf-8") as f:
         f.write(tex)
-        '''for i in tex:
-            try:
-                f.write(i)
-            except Exception as e:
-                print(f'Our exception in {e}', end='\n\n')
-                print(i)
-        '''
-        
     # Convenience function for removing temporary files
     def remove_temp_files(basename_):
         filenames = [f'{basename_}.tex', f'{basename_}.aux',
@@ -114,9 +234,11 @@ def create_latex_pdf(character, basename, template, keep_temp_files=False):
     tex_command_line = ['pdflatex', '--output-directory', output_dir,
                         '-halt-on-error', '-interaction=nonstopmode',
                         tex_file]
+    passes = 2 if use_dnd_decorations else 1
     try:
-        result = subprocess.run(tex_command_line,
-                                stdout=subprocess.DEVNULL, timeout=30)
+        for i in range(passes):
+            result = subprocess.run(tex_command_line,
+                                    stdout=subprocess.DEVNULL, timeout=30)
     except FileNotFoundError:
         # Remove temporary files
         remove_temp_files(basename)
@@ -212,7 +334,7 @@ def create_character_pdf(character, basename, flatten=False):
         'Race ': str(character.race),
         'Alignment': character.alignment,
         'XP': str(character.xp),
-        'Inspiration': str(character.inspiration),
+        'Inspiration': str('Yes' if character.inspiration else 'No'),
         # Abilities
         'ProfBonus': mod_str(character.proficiency_bonus),
         'STRmod': str(character.strength.value),
@@ -323,11 +445,13 @@ def create_character_pdf(character, basename, flatten=False):
         fields[atk_field] = '{:+d}'.format(weapon.attack_modifier)
         fields[dmg_field] = f'{weapon.damage}/{weapon.damage_type}'
     # Other attack information
-    attack_str = f'Armor: {character.armor}'
-    attack_str += '\n \n'
-    attack_str += f'Shield: {character.shield}'
-    attack_str += '\n \n'
-    attack_str += character.attacks_and_spellcasting
+    attack = []
+    if character.armor:
+        attack.append(f'Armor: {character.armor}')
+    if character.shield:
+        attack.append(f'Shield: {character.shield}')
+    attack.append(character.attacks_and_spellcasting)
+    attack_str = '\n\n'.join(attack)
     fields['AttacksSpellcasting'] = text_box(attack_str)
     # Other proficiencies and languages
     prof_text = "Proficiencies:\n" + text_box(character.proficiencies_text)
@@ -342,7 +466,7 @@ def create_character_pdf(character, basename, flatten=False):
 
 def make_pdf(fields: dict, src_pdf: str, basename: str, flatten: bool=False):
     """Create a new PDF by applying fields to a src PDF document.
-    
+
     Parameters
     ==========
     fields :
@@ -356,7 +480,7 @@ def make_pdf(fields: dict, src_pdf: str, basename: str, flatten: bool=False):
     flatten :
       If truthy, the PDF will be collapsed so it is no longer
       editable.
-    
+
     """
     try:
         result = _make_pdf_pdftk(fields, src_pdf, basename, flatten)
@@ -419,7 +543,7 @@ def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False):
     """More robust way to make a PDF, but has a hard dependency."""
     # Create the actual FDF file
     fdfname = basename + '.fdf'
-    
+
     fdf = forge_fdf("", fields, [], [], [])
     fdf_file = open(fdfname, "wb")
     fdf_file.write(fdf)
@@ -434,20 +558,27 @@ def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False):
     subprocess.call(popenargs)
     # Clean up temporary files
     os.remove(fdfname)
-    
-    
-def make_sheet(character_file, character=None, flatten=False, debug=False):
+
+
+def make_sheet(character_file, character=None, flatten=False, fancy_decorations=False, debug=False):
     """Prepare a PDF character sheet from the given character file.
-    
+
     Parameters
     ----------
     character_file : str
-        File (.py) to load character from. Will save PDF using same name
+      File (.py) to load character from. Will save PDF using same name
     character : Character, optional
-        If provided, will not load from the character file, just use file
-        for PDF name
+      If provided, will not load from the character file, just use
+      file for PDF name
     flatten : bool, optional
-        If true, the resulting PDF will look better and won't be fillable form.
+      If true, the resulting PDF will look better and won't be
+      fillable form.
+    fancy_decorations : bool, optional
+      Use fancy page layout and decorations for extra sheets, namely
+      the dnd style file: https://github.com/rpgtex/DND-5e-LaTeX-Template.
+    debug : bool, optional
+      Provide extra info and preserve temporary files.
+
     """
     if character is None:
         character = _char.Character.load(character_file)
@@ -462,13 +593,16 @@ def make_sheet(character_file, character=None, flatten=False, debug=False):
         # Create spell sheet
         spell_base = '{:s}_spells'.format(
             os.path.splitext(character_file)[0])
-        create_spells_pdf(character=character, basename=spell_base, flatten=flatten)
+        create_spells_pdf(character=character, basename=spell_base,
+                          flatten=flatten)
         sheets.append(spell_base + '.pdf')
     if len(character.features) > 0:
         feat_base = '{:s}_feats'.format(
             os.path.splitext(character_file)[0])
         try:
-            create_features_pdf(character=character, basename=feat_base, keep_temp_files=debug)
+            create_features_pdf(character=character,
+                                basename=feat_base, keep_temp_files=debug,
+                                use_dnd_decorations=fancy_decorations)
         except exceptions.LatexNotFoundError as e:
             log.warning('``pdflatex`` not available. Skipping features book '
                         f'for {character.name}')
@@ -478,18 +612,35 @@ def make_sheet(character_file, character=None, flatten=False, debug=False):
         # Create spell book
         spellbook_base = os.path.splitext(character_file)[0] + '_spellbook'
         try:
-            create_spellbook_pdf(character=character, basename=spellbook_base, keep_temp_files=debug)
+            create_spellbook_pdf(character=character,
+                                 basename=spellbook_base, keep_temp_files=debug,
+                                 use_dnd_decorations=fancy_decorations)
         except exceptions.LatexNotFoundError as e:
             log.warning('``pdflatex`` not available. Skipping spellbook '
                         f'for {character.name}')
         else:
             sheets.append(spellbook_base + '.pdf')
+    #Create a list of Artificer infusions
+    infusions = getattr(character, 'infusions', [])
+    if len(infusions) > 0:
+        infusions_base = os.path.splitext(character_file)[0] + '_infusions'
+        try:
+            create_infusions_pdf(character=character,
+                                 basename=infusions_base, keep_temp_files=debug,
+                                 use_dnd_decorations=fancy_decorations)
+        except exceptions.LatexNotFoundError as e:
+            log.warning('``pdflatex`` not available. Skipping infusions list '
+                        f'for {character.name}')
+        else:
+            sheets.append(infusions_base + '.pdf')
     # Create a list of Druid wild_shapes
     wild_shapes = getattr(character, 'wild_shapes', [])
     if len(wild_shapes) > 0:
         shapes_base = os.path.splitext(character_file)[0] + '_wild_shapes'
         try:
-            create_druid_shapes_pdf(character=character, basename=shapes_base, keep_temp_files=debug)
+            create_druid_shapes_pdf(character=character,
+                                    basename=shapes_base, keep_temp_files=debug,
+                                    use_dnd_decorations=fancy_decorations)
         except exceptions.LatexNotFoundError as e:
             log.warning('``pdflatex`` not available. Skipping wild shapes list '
                         f'for {character.name}')
@@ -502,7 +653,7 @@ def make_sheet(character_file, character=None, flatten=False, debug=False):
 
 def merge_pdfs(src_filenames, dest_filename, clean_up=False):
     """Merge several PDF files into a single final file.
-    
+
     src_filenames
       Iterable of source PDF file paths to use.
     dest_filename
@@ -511,7 +662,7 @@ def merge_pdfs(src_filenames, dest_filename, clean_up=False):
     clean_up : optional
       If truthy, the ``src_filenames`` will be deleted once the
       ``dest_filename`` has been created.
-    
+
     """
     popenargs = (PDFTK_CMD, *src_filenames, 'cat', 'output', dest_filename)
     try:
@@ -526,42 +677,78 @@ def merge_pdfs(src_filenames, dest_filename, clean_up=False):
                 os.remove(sheet)
 
 
-load_character_file = _char.read_character_file
+load_character_file = readers.read_character_file
 
 
+def _build(filename, args) -> int:
+    basename = filename.stem
+    print(f"Processing {basename}...")
+    try:
+        make_sheet(character_file=filename, flatten=(not args.editable),
+                   debug=args.debug, fancy_decorations=args.fancy_decorations)
+    except exceptions.CharacterFileFormatError as e:
+        # Only raise the failed exception if this file is explicitly given
+        print(f'invalid {basename}')
+        if args.filename:
+            raise
+    except Exception as e:
+        print(f'{basename} failed')
+        raise
+    else:
+        print(f"{basename} done")
+    return 1
+
 def main():
     # Prepare an argument parser
     parser = argparse.ArgumentParser(
         description='Prepare Dungeons and Dragons character sheets as PDFs')
-    parser.add_argument('filename', type=str, nargs="?",
-                        help="Python file with character definition")
+    parser.add_argument('filename', type=str, nargs="*",
+                        help="File with character definition, or directory containing such files")
     parser.add_argument('--editable', '-e', action="store_true",
-                        help="Keep the PDF fields in place once processed.")
+                        help="Keep the PDF fields in place once processed")
+    parser.add_argument('--recursive', '-r', action="store_true",
+                        help="Descend into subfolders looking for character files")
+    parser.add_argument('--fancy-decorations', '--fancy', '-F', action="store_true",
+                        help=("Render extra pages using fancy decorations "
+                              "(experimental, requires https://github.com/rpgtex/DND-5e-LaTeX-Template)"))
     parser.add_argument('--debug', '-d', action="store_true",
                         help="Provide verbose logging for debugging purposes.")
     args = parser.parse_args()
     # Prepare logging if necessary
     if args.debug:
         logging.basicConfig(level=logging.DEBUG)
-    # Process the requested files
-    if args.filename is None:
-        filenames = [f for f in os.listdir('.') if os.path.splitext(f)[1] == '.py']
+    # Build the true list of filenames
+    input_filenames = args.filename
+    known_extensions = readers.readers_by_extension.keys()
+    if input_filenames == []:
+        input_filenames = [Path()]
     else:
-        filenames = [args.filename]
-    for filename in filenames:
-        print(f"Processing {os.path.splitext(filename)[0]}...", end='')
-        try:
-            make_sheet(character_file=filename, flatten=(not args.editable), debug=args.debug)
-        except exceptions.CharacterFileFormatError as e:
-            # Only raise the failed exception if this file is explicitly given
-            print('invalid')
-            if args.filename:
-                raise
-        except Exception as e:
-            print('failed')
-            raise
-        else:
-            print("done")
+        input_filenames = [Path(f) for f in input_filenames]
+    def get_char_files(fpath, parse_dirs=False):
+        valid_files = []
+        if fpath.is_dir() and parse_dirs:
+            for f in fpath.iterdir():
+                valid_files.extend(get_char_files(f, parse_dirs=args.recursive))
+        elif fpath.suffix in known_extensions:
+            valid_files.append(fpath)
+        return valid_files
+    temp_filenames = []
+    for fpath in input_filenames:
+        temp_filenames.extend(get_char_files(fpath, parse_dirs=True))
+    # IMPORTANT: Check that the files are valid dungeonsheets files without importing them
+    filenames = []
+    version_re = re.compile(r"^dungeonsheets_version = [\'\"](?P<version>[0-9.]+)[\'\"]\s*$", re.MULTILINE)
+    for fpath in temp_filenames:
+        with open(fpath, mode='r') as fp:
+            if version_re.search(fp.read()) or fpath.suffix != '.py':
+                filenames.append(fpath)
+    # Process the requested files
+    if args.debug:
+        for filename in filenames:
+            _build(filename, args)
+    else:
+        with Pool(cpu_count()) as p:
+            p.starmap(_build, product(filenames, [args]))
 
 
 if __name__ == '__main__':
