@@ -1,4 +1,4 @@
-from .spells import Spell
+from dungeonsheets.spells.spells import Spell
 
 
 class DancingLights(Spell):
