@@ -1,11 +1,11 @@
-from .spells import Spell
+from dungeonsheets.spells.spells import Spell
 
 
 class GaseousForm(Spell):
-    """You transform a willing creature you touch, along with everything it's wearing 
-    and carrying, into a misty cloud for the duration. The spell ends if the 
+    """You transform a willing creature you touch, along with everything it's wearing
+    and carrying, into a misty cloud for the duration. The spell ends if the
     creature drops to 0 hit points. An incorporeal creature isn't affected.
-    
+
     While in this form, the target's only method of movement is a
     flying speed of 10 feet.  The target can enter and occupy the
     space of another creature. The target has resistance to nonmagical
@@ -15,7 +15,7 @@ class GaseousForm(Spell):
     liquids as though they were solid surfaces. The target can't fall
     and remains hovering in the air even when stunned or otherwise
     incapacitated.
-    
+
     While in the form of a misty cloud, the target can't talk or
     manipulate objects, and any objects it was carrying or holding
     can't be dropped, used, or otherwise interacted with. The target
@@ -40,17 +40,17 @@ class Gate(Spell):
     portal is a circular opening, which you can make 5 to 20 feet in
     diameter. You can orient the portal in any direction you
     choose. The portal lasts for the duration.
-    
+
     The portal has a front and a back on each plane where it
     appears. Travel through the portal is possible only by moving
     through its front. Anything that does so is instantly transported
     to the other plane, appearing in the unoccupied space nearest to
     the portal.
-    
+
     Deities and other planar rulers can prevent portals created by
     this spell from opening in their presence or anywhere within their
     domains.
-    
+
     When you cast this spell, you can speak the name of a specific
     creature (a pseudonym, title, or nickname doesn't work). If that
     creature is on a plane other than the one you are on, the portal
@@ -77,20 +77,20 @@ class Geas(Spell):
     """You place a magical command on a creature that you can see within
      range, forcing it to carry out some service or refrain from some
      action or course of actiity as you decide.
-    
+
     If the creature can understand you, it must succeed on a Wisdom
     saving throw or become charmed by you for the duration. While the
     creature is charmed by you, it takes 5d10 psychic damage each time
     it acts in a manner directly counter to your instructions, but no
     more than once each day. A creature that can't understand you is
     unaffected by the spell.
-    
+
     You can issue any command you choose, short of an activity that
     would result in certain death. Should you issue a suicidal
     command, the spell ends. You can end the spell early by using an
     action to dismiss it. A remove curse, greater restoration, or wish
     spell also ends it.
-    
+
     **At Higher Levels:** When you cast this spell usinga spell slot of
     7th or 8th level, the duration is 1 year.  When you cast this
     spell using a spell slot of 9th level, the spell lasts until it is
@@ -110,9 +110,9 @@ class Geas(Spell):
 
 
 class GentleRepose(Spell):
-    """You touch a corpse or other remains. For the duration, the target is protected 
+    """You touch a corpse or other remains. For the duration, the target is protected
     from decay and can't become undead.
-    
+
     The spell also effectively extends the time limit on raising the
     target from the dead, since days spent under the influence of this
     spell don't count against the time limit of spells such as raise
@@ -181,14 +181,14 @@ class Glibness(Spell):
 class GlobeOfInvulnerability(Spell):
     """An immobile, faintly shimmering barrier springs into existence in a
     10-foot radius around you and remains for the duration.
-    
+
     Any spell of 5th level or lower cast from outside the barrier
     can't affect creatures or objects within it, even if the spell is
     cast using a higher level spell slot. Such a spell can target
     creatures and objects within the barrier, but the spell has no
     effect on them.  Similarly, the area within the barrier is
     excluded from the areas affected by such spells.
-    
+
     **At Higher Levels:** When you cast this spell using a spell slot
     of 7th level or higher, the barrier blocks spells of one level
     higher for each slot level above 6th.
@@ -211,17 +211,17 @@ class GlyphOfWarding(Spell):
     creatures, either upon a surface (such as a table or a section of
     floor or wall) or within an object that can be closed (such as a
     book, a scroll, or a treasure chest) to conceal the glyph.
-    
+
     If you choose a surface, the glyph can cover an area of the
     surface no larger than 10 feet in diameter. If you choose an
     object, that object must remain in its place; if the object is
     moved more than 10 feet from where you cast this spell, the glyph
     is broken, and the spell ends without being triggered.
-    
+
     The glyph is nearly invisible and requires a successful
     Intelligence (Investigation) check against your spell save DC to
     be found.
-    
+
     You decide what triggers the glyph when you cast the spell. For
     glyphs inscribed on a surface, the most typical triggers include
     touching or standing on the glyph, removing another object
@@ -231,17 +231,17 @@ class GlyphOfWarding(Spell):
     triggers include opening that object, approaching within a certain
     distance of the object, or seeing or reading the glyph. Once a
     glyph is triggered, this spell ends.
-    
+
     You can further refine the trigger so the spell activates only
     under certain circumstances or according to physical
     characteristics (such as height or weight), creature kind (for
     example, the ward could be set to affect aberrations or drow), or
     alignment. You can also set conditions for creatures that don't
     trigger the glyph, such as those who say a certain password.
-    
+
     When you inscribe the glyph, choose explosive runes or a spell
     glyph.
-    
+
     **Explosive Runes**
     When triggered, the glyph erupts with magical energy in a
     20-foot-radius sphere centered on the glyph. The sphere spreads
@@ -249,7 +249,7 @@ class GlyphOfWarding(Spell):
     saving throw. A creature takes 5d8 acid, cold, fire, lightning, or
     thunder damage on a failed saving throw (your choice when you
     create the glyph), or half as much damage on a successful one.
-    
+
     **Spell Glyph**
     You can store a prepared spell of 3rd level or lower in the glyph
     by casting it as part of creating the glyph. The spell must target
@@ -262,7 +262,7 @@ class GlyphOfWarding(Spell):
     traps, they appear as close as possible to the intruder and attack
     it. If the spell requires concentration, it lasts until the end of
     its full duration.
-    
+
     **At Higher Levels:** When you cast this spell using a spell slot
     of 4th Level or higher, the damage of an explosive runes glyph
     increases by 1d8 for each slot level above 3rd. If you create a
@@ -367,10 +367,10 @@ class GreaterRestoration(Spell):
     """You imbue a creature you touch with positive energy to undo a
     debilitating effect. You can reduce the target's exhaustion level
     by one, or end one of the following effects on the target:
-    
-    - One effect that charmed or petrified the target 
-    - One curse, including the target's attunement to a cursed magic item 
-    - Any reduction to one of the target's ability scores 
+
+    - One effect that charmed or petrified the target
+    - One curse, including the target's attunement to a cursed magic item
+    - Any reduction to one of the target's ability scores
     - One effect reducing the target's hit point maximum
 
     """
@@ -441,19 +441,19 @@ class GuardianOfNature(Spell):
     powerful guardian. The transformation lasts until the spell
     ends. You choose one of the following forms to assume: Primal
     Beast or Great Tree.
-    
+
     **Primal Beast.** Bestial fur covers your body, your facial
     features become feral, and you gain the following benefits:
-    
+
     - Your walking speed increases by 10 feet.
     - You gain darkvision with a range of 120 feet.
     - You make Strength-based attack rolls with advantage.
     - Your melee weapon attacks deal an extra 1d6 force damage on a
       hit.
-    
+
     **Great Tree.** Your skin appears barky, leaves sprout from your
     hair, and you gain the following benefits:
-    
+
     - You gain 10 temporary hit points.
     - You make Constitution saving throws with advantage.
     - You make Dexterity- and Wisdom-based attack rolls with advantage.
@@ -480,54 +480,54 @@ class GuardsAndWards(Spell):
     tall, and shaped as you desire. You can ward several stories of a
     stronghold by dividing the area among them, as long as you can
     walk into each contiguous area while you are casting the spell.
-    
+
     When you cast this spell, you can specify individuals that are
     unaffected by any or all of the effects that you choose. You can
     also specify a password that, when spoken aloud, makes the speaker
     immune to these effects.
-    
+
     Guards and wards creates the following effects within the warded
     area.
-    
+
     Corridors: Fog fills all the warded corridors, making them heavily
     obscured. In addition, at each intersection or branching passage
     offering a choice of direction, there is a 50 percent chance that
     a creature other than you will believe it is going in the opposite
     direction from the one it chooses.
-    
+
     Doors: All doors in the warded area are magically locked, as if
     sealed by an arcane lock spell. In addition, you can cover up to
     ten doors with an illusion (equivalent to the illusory object
     function of the m inor illusion spell) to make them appear as
     plain sections of wall.
-    
+
     Stairs: Webs fill all stairs in the warded area from top to
     bottom, as the web spell. These strands regrow in 10 minutes if
     they are burned or torn away while guards and wards lasts.
-    
+
     Other Spell Effect: You can place your choice of one of the
     following magical effects within the warded area of the
     stronghold.
-    
+
     - Place dancing lights in four corridors. You can designate a
       simple program that the lights repeat as long as guards and
       wards lasts.
-    
+
     - Place magic mouth in two locations.
-    
+
     - Place stinking cloud in two locations. The vapors appear in the
       places you designate; they return within 10 minutes if dispersed
       by wind while guards and wards lasts.
-    
+
     - Place a constant gust of wind in one corridor or room.
-    
+
     - Place a suggestion in one location. You select an area of up to
       5 feet square, and any creature that enters or passes through
       the area receives the suggestion mentally.
-    
+
     The whole warded area radiates magic. A dispel magic cast on a
     specific effect, if successful, removes only that effect.
-    
+
     You can create a permanently guarded and warded structure by
     casting this spell there every day for one year.
 
@@ -590,7 +590,7 @@ class GuidingHand(Spell):
     unoccupied space you can see within range. The hand exists for the
     duration, but it disappears if you teleport or you travel to a
     different plane of existence.
-    
+
     When the hand appears, you name one major landmark, such as a
     city, mountain, castle, or battlefield on the same plane of
     existence as you.  Someone in history must have visited the site
@@ -599,10 +599,10 @@ class GuidingHand(Spell):
     moves away from you at the same speed you moved, and it moves in
     the direction of the landmark, always remaining 5 feet away from
     you.
-    
+
     If you don't move toward the hand, it remains in place until you
     do and beckons for you to follow once every 1d4 minutes.
-    
+
     """
     name = "Guiding Hand"
     level = 1
@@ -619,15 +619,15 @@ class GuidingHand(Spell):
 class Gust(Spell):
     """You seize the air and compel it to create one of the following
     effects at a point you can see within range:
-    
+
     - One Medium or smaller creature that you choose must succeed on a
       Strength saving throw or be pushed up to 5 feet away from you.
-    
+
     - You create a small blast of air capable of moving one object
       that is neither held nor carried and that weighs no more than 5
       pounds. The object is pushed up to 10 feet away from you. It
       isn't pushed with enough force to cause damage.
-    
+
     - You create a harmless sensory affect using air, such as causing
       leaves to rustle, wind to slam shutters shut, or your clothing
       to ripple in a breeze.
@@ -651,15 +651,15 @@ class GustOfWind(Spell):
     that starts its turn in the line must succeed on a Strength saving
     throw or be pushed 15 feet away from you in a direction following
     the line.
-    
+
     Any creature in the line must spend 2 feet of movement for every 1
     foot it moves when moving closer to you.
-    
+
     The gust disperses gas or vapor, and it extinguishes candles,
     torches, and similar unprotected flames in the area. It causes
     protected flames, such as those of lanterns, to dance wildly and
     has a 50 percent chance to extinguish them.
-    
+
     As a bonus action on each of your turns before the spell ends, you
     can change the direction in which the line blasts from you.
 
