@@ -1,4 +1,4 @@
-from .spells import Spell
+from dungeonsheets.spells.spells import Spell
 
 
 class WallOfFire(Spell):
@@ -45,7 +45,7 @@ class WallOfForce(Spell):
     for the duration. If the wall cuts through a creature's space when
     it appears, the creature is pushed to one side of the wall (your
     choice which side).
-    
+
     Nothing can physically pass through the wall. It is immune to all
     damage and can't be dispelled by dispel magic. A disintegrate
     spell destroys the wall instantly, however. The wall also extends
@@ -72,13 +72,13 @@ class WallOfIce(Spell):
     10-foot-square panels. Each panel must be contiguous with another
     panel. In any form, the wall is 1 foot thick and lasts for the
     duration.
-    
+
     If the wall cuts through a creature's space when it appears, the
     creature within its area is pushed to one side of the wall and
     must make a Dexterity saving throw. On a failed save, the creature
     takes 10d6 cold damage, or half as much damage on a successful
     save.
-    
+
     The wall is an object that can be damaged and thus breached. It
     has AC 12 and 30 hit points per 10-foot section, and it is
     vulnerable to fire damage. Reducing a 10-foot section of wall to 0
@@ -87,7 +87,7 @@ class WallOfIce(Spell):
     frigid air for the first time on a turn must make a Constitution
     saaving throw. The creature takes 5f6 cold damage on a failed
     save, or half as much damage on a successful one.
-    
+
     **At Higher Levels:** When you cast this spell using a spell slot
     of 7th level or higher, the damage the wall deals when it appears
     increases by 2d6, and the damage from passing through the sheet of
@@ -115,14 +115,14 @@ class WallOfLight(Spell):
     sight, but creatures and objects can pass through it. It emits
     bright light out to 120 feet and dim light for an additional 120
     feet.
-    
+
     When the wall appears, each creature in its area must make a
     Constitution saving throw. On a failed save, a creature takes 4d8
     radiant damage, and it is blinded for 1 minute. On a successful
     save, it takes half as much damage and isn't blinded. A blinded
     creature can make a Constitution saving throw at the end of each
     of its turns, ending the effect on itself on a success.
-    
+
     A creature that ends its turn in the wall's area takes 4d8 radiant
     damage.  Until the spell ends, you can use an action to launch a
     beam of radiance from the wall at one creature you can see within
@@ -130,7 +130,7 @@ class WallOfLight(Spell):
     takes 4d8 radiant damage. Whether you hit or miss, reduce the
     length of the wall by 10 feet. If the wall's length drops to 0
     feet, the spell ends.
-    
+
     **At Higher Levels:** When you cast this spell using a spell slot
     of 6th level or higher, the damage increases by 1d8 for each slot
     level above 5th.
@@ -173,29 +173,29 @@ class WallOfStone(Spell):
     composed of ten 10-foot- by-10-foot panels. Each panel must be
     contiguous with at least on other panel.  Alternatively, you can
     create 10-foot-by-20-foot panels that are only 3 inches thick.
-    
+
     If the wall cuts through a creature's space when it appears, the
     creature is pushed to one side of the wall (your choice). If a
     creature would be surrounded on all sides by the wall (or the wall
     and another solid surface), that creature can make a Dexterity
     saving throw. On a success, it can use its reaction to move up to
     its speed so that it is no longer enclosed by the wall.
-    
+
     The wall can have any shape you desire, though it can't occupy the
     same space as a creature or object. the wall doesn't need to be
     vertical or resting on any firm foundation. It must, however,
     merge with and be solidly supported by existing stone. Thus you
     can use this spell to bridge a chasm or create a ramp.
-    
+
     If you create a span greater than 20 feet in length, you must
     halve the size of each panel to create supports. You can crudely
     shape the wall to create crenellations, battlements, and so on.
-    
+
     The wall is an object made of stone that can be damaged and thus
     breached. Each panel has AC 15 and 30 hit points per inch of
     thickness. Reducing a panel to 0 hit points destroys it and might
     cause connected panels to collapse at the DM's discretion.
-    
+
     If you maintain your concentration on this spell for its whole
     duration, the wall becomes permanent and can't be
     dispelled. Otherwise, the wall disappears when the spell ends.
@@ -249,14 +249,14 @@ class WallOfThorns(Spell):
 
 class WallOfWater(Spell):
     """(a drop of water)
-    
+
     You conjure up a wall of water on the ground at a point you can
     see within range. You can make the wall up to 30 feet long, 10
     feet high, and 1 foot thick, or you can make a ringed wall up to
     20 feet in diameter, 20 feet high, and 1 foot thick. The wall
     vanishes when the spell ends. The wall's space is difficult
     terrain.
-    
+
     Any ranged weapon attack that enters the wall's space has
     disadvantage on the attack roll, and fire damage is halved if the
     fire effect passes through the wall to reach its target. Spells
@@ -310,7 +310,7 @@ class WardingWind(Spell):
     """A strong wind (20 miles per hour) blows around you in a 10-foot
     radius and moves with you, remaining centered on you. The wind
     lasts for the spell's duration.
-    
+
     The wind has the following effects:
     - It deafens you and other creatures in its area.
     - It extinguishes unprotected flames in its area that are
@@ -379,7 +379,7 @@ class WaterySphere(Spell):
     you can see within range. The sphere can hover in the air, but no
     more than 10 feet off the ground. The sphere remains for the
     spell's duration.
-    
+
     Any creature in the sphere's space must make a Strength saving
     throw. On a successful save, a creature is ejected from that space
     to the nearest unoccupied space outside it.  A Huge or larger
@@ -387,25 +387,25 @@ class WaterySphere(Spell):
     save, a creature is restrained by the sphere and is engulfed by
     the water. At the end of each of its turns, a restrained target
     can repeat the saving throw.
-    
+
     The sphere can restrain a maximum of four Medium or smaller
     creatures or one Large creature. If the sphere restrains a
     creature in excess of these numbers, a random creature that was
     already restrained by the sphere falls out of it and lands prone
     in a space within 5 feet of it.
-    
+
     As an action, you can move the sphere up to 30 feet in a straight
     line. If it moves over a pit, cliff, or other drop, it safely
     descends until it is hovering 10 feet over ground. Any creature
     restrained by the sphere moves with it. You can ram the sphere
     into creatures, forcing them to make the saving throw, but no more
     than once per turn.
-    
+
     When the spell ends, the sphere falls to the ground and
     extinguishes all normal flames within 30 feet of it. Any creature
     restrained by the sphere is knocked prone in the space where it
     falls.
-    
+
     """
     name = "Watery Sphere"
     level = 4
@@ -424,22 +424,22 @@ class Web(Spell):
     choice within range.  The webs fill a 20-foot cube from that point
     for the duration. The webs are difficult terrain and lightly
     obscure their area.
-    
+
     If the webs aren't anchored between two solid masses (such as
     walls or trees) or layered across a floor, wall, or ceiling, the
     conjured web collapses on itself, and the spell ends at the start
     of your next turn. Webs layered over a flat surface have a depth
     of 5 feet.
-    
+
     Each creature that starts its turn in the webs or that enters them
     during its turn must make a Dexterity saving throw. On a failed
     save, the creature is restrained as long as it remains in the webs
     or until it breaks free.
-    
+
     A creature restrained by the webs can use its action to make a
     Strength check against your spell save DC. If it succeeds, it is
     no longer restrained.
-    
+
     The webs are flammable. Any 5-foot cube of webs exposed to fire
     burns away in 1 round, dealing 2d4 fire damage to any creature
     that starts its turn in the fire.
@@ -463,7 +463,7 @@ class Weird(Spell):
     creature in a 30-foot-radius sphere centered on a point of your
     choice within range must make a Wisdom saving throw. On a failed
     save, a creature becomes frightened for the duration.
-    
+
     The illusion calls on the creature's deepest fears, manifesting
     its worst nightmares as an implacable threat. At the end of each
     of the frightened creature's turns, it must succeed on a Wisdom
@@ -491,7 +491,7 @@ class Whirlwind(Spell):
     direction along the ground. The whirlwind sucks up any Medium or
     smaller objects that aren't secured to anything and that aren't
     worn or carried by anyone.
-    
+
     A creature must make a Dexterity saving throw the first time on a
     turn that it enters the whirlwind or that the whirlwind enters its
     space, including when the whirlwind first appears. A creature
@@ -502,7 +502,7 @@ class Whirlwind(Spell):
     ends. When a creature starts its turn restrained by the whirlwind,
     the creature is pulled 5 feet higher inside it, unless the
     creature is at the top.
-    
+
     A restrained creature moves with the whirlwind and falls when the
     spell ends, unless the creature has some means to stay aloft. A
     restrained creature can use an action to make a Strength or
@@ -568,7 +568,7 @@ class WindWalk(Spell):
     which time a creature is incapacitated and can't move. Until the
     spell ends, a creature can revert to cloud form, which also
     requires the 1-minute transformation.
-    
+
     If a creature is in cloud form and flying when the effect ends,
     the creature descends 60 feet per round for 1 minute until it
     lands, which it does safely. If it can't land after 1 minute, the
@@ -590,16 +590,16 @@ class WindWalk(Spell):
 class WindWall(Spell):
     """A wall of strong wind rises from the ground at a point you choose
     within range.
-    
+
     You can make the wall up to 50 feet long, 15 feet high, and 1 foot
     thick. You can shape the wall in any way you choose so long as it
     makes one continuous path along the ground. The wall lasts for the
     duration.
-    
+
     When the wall appears, each creature within its area must make a
     Strength saving throw. A creature takes 3d8 bludgeoning damage on
     a failed save, or half as much damage on a successful one.
-    
+
     The strong wind keeps fog, smoke, and other gases at bay. Small or
     smaller flying creatures or objects can't pass through the
     wall. Loose, lightweight materials brought into the wall fly
@@ -626,30 +626,30 @@ class Wish(Spell):
     """Wish is the mightiest spell a mortal creature can cast. By simply
     speaking aloud, you can alter the very foundations of reality in
     accord with your desires.
-    
+
     The basic use of this spell is to duplicate any other spell of 8th
     level or lower. You don't need to meet any requirements in that
     spell, including costly components. The spell simply takes effect.
     Alternatively, you can create one of the following effects of your
     choice:
-    
+
     - You create one object of up to 25,000 gp in value that isn't a
       magic item. The object can be no more than 300 feet in any
       dimension, and it appears in an unoccupied space you can see on
       the ground.
-    
+
     - You allow up to twenty creatures that you can see to regain all
       hit points, and you end all effects on them described in the
       greater restoration spell.
-    
+
     - You grant up to ten creatures that you can see resistance to a
       damage type you choose.
-    
+
     - You grant up to ten creatures you can see immunity to a single
       spell or other magical effect for 8 hours. For instance, you
       could make yourself and all your com panions immune to a lich's
       life drain attack.
-    
+
     - You undo a single recent event by forcing a reroll of any roll
       made within the last round (including your last turn). Reality
       reshapes itself to accommodate the new result. For example, a
@@ -657,7 +657,7 @@ class Wish(Spell):
       critical hit, or a friend's failed save. You can force the
       reroll to be made with advantage or disadvantage, and you can
       choose whether to use the reroll or the original roll.
-    
+
     You might be able to achieve something beyond the scope of the
     above examples. State your wish to the DM as precisely as
     possible.  The DM has great latitude in ruling what occurs in such
@@ -670,7 +670,7 @@ class Wish(Spell):
     effectively removing you from the game. Similarly, wishing for a
     legendary magic item or artifact might instantly transport you to
     the presence of the item's current owner.
-    
+
     The stress of casting this spell to produce any effect other than
     duplicating another spell weakens you. After enduring that stress,
     each time you cast a spell until you finish a long rest, you take
@@ -698,18 +698,18 @@ class Wish(Spell):
 class WitchBolt(Spell):
     """A beam of crackling, blue energy lances out toward a creature within range,
     forming a sustained arc of lightning between you and the target.
-    
+
     Make a ranged spell attack against that creature. On a hit, the
     target takes 1d12 lightning damage, and on each of your turns for
     the duration, you can use your action to deal 1d12 lightning
     damage to the target automatically. The spell ends if you use your
     action to do anything else. The spell also ends if the target is
     ever outside the spell's range or if it has total cover from you.
-    
+
     **At Higher Levels:** When you cast this spell using a spell slot
     of 2nd level or higher, the initial damage increases by 1d12 for
     each slot level above 1st.
-    
+
     """
     name = "Witch Bolt"
     level = 1
@@ -751,7 +751,7 @@ class WordOfRecall(Spell):
     space to the spot you designated when you prepared your sanctuary
     (see below). If you cast this spell without first preparing a
     sanctuary, the spell has no effect.
-    
+
     You must designate a sanctuary by casting this spell within a
     location, such as a temple, dedicated to or strongly linked to
     your deity. If you attempt to cast the spell in this manner in an
